-----------------
From all rows in a CSV
-----------------

.. literalinclude:: ../../../../../examples/user/prompt_from_all_csv.py
    :caption: See `prompt_from_all_csv.py <https://github.com/IBM/ibm-generative-ai/blob/main/examples/user/prompt_from_all_csv.py>`_ on GitHub.

-----------------
From a random row in a CSV
-----------------

.. literalinclude:: ../../../../../examples/user/prompt_csv_random_rows.py
    :caption: See `prompt_csv_random_rows.py <https://github.com/IBM/ibm-generative-ai/blob/main/examples/user/prompt_csv_random_rows.py>`_ on GitHub.

-----------------
From a JSON
-----------------

.. literalinclude:: ../../../../../examples/user/self_instruct.py
    :caption: See `self_instruct.py <https://github.com/IBM/ibm-generative-ai/blob/main/examples/user/self_instruct.py>`_ on GitHub.

-----------------
From a dataframe
-----------------

.. literalinclude:: ../../../../../examples/user/prompt_from_dataframe.py
    :caption: See `prompt_from_dataframe.py <https://github.com/IBM/ibm-generative-ai/blob/main/examples/user/prompt_from_dataframe.py>`_ on GitHub.

-----------------
Inferring variables from CSV header
-----------------

.. literalinclude:: ../../../../../examples/user/prompts_adult_dataset/prompt_generation_with_headers.py
    :caption: See `prompt_generation_with_headers.py <https://github.com/IBM/ibm-generative-ai/blob/main/examples/user/prompts_adult_dataset/prompt_generation_with_headers.py>`_ on GitHub.
